@@ -15,6 +15,7 @@
 #include <girara/shortcuts.h>
 #include <girara/config.h>
 #include <girara/commands.h>
+#include <girara/template.h>
 #include <girara/utils.h>
 #include <glib/gi18n.h>
 
@@ -31,6 +32,22 @@ static void cb_jumplist_change(girara_session_t* session, const char* UNUSED(nam
   zathura_jumplist_set_max_size(zathura, MAX(0, *ivalue));
 }
 
+static void cb_color(girara_session_t* session, const char* name, girara_setting_type_t UNUSED(type), const void* value,
+                     void* UNUSED(data)) {
+  g_return_if_fail(session != NULL && value != NULL);
+  GiraraTemplate* csstemplate = girara_session_get_template(session);
+
+  const char* str_value = value;
+
+  GdkRGBA color = {0, 0, 0, 0};
+  gdk_rgba_parse(&color, str_value);
+
+  char* colorstr = gdk_rgba_to_string(&color);
+  girara_template_set_variable_value(csstemplate, name, colorstr);
+  g_free(colorstr);
+}
+
+
 static void cb_color_change(girara_session_t* session, const char* name, girara_setting_type_t UNUSED(type),
                             const void* value, void* UNUSED(data)) {
   g_return_if_fail(value != NULL);
@@ -213,12 +230,14 @@ void config_load_default(zathura_t* zathura) {
 
   /* clang-format off */
   /* zathura settings */
-  girara_setting_add(gsession, "database",              "plain",      STRING, true,  _("Database backend"),         NULL, NULL);
+  girara_setting_add(gsession, "database",              "sqlite",     STRING, true,  _("Database backend"),         NULL, NULL);
   girara_setting_add(gsession, "filemonitor",           "glib",       STRING, true,  _("File monitor backend"),     NULL, NULL);
   int_value = 10;
   girara_setting_add(gsession, "zoom-step",             &int_value,   INT,    false, _("Zoom step"),                NULL, NULL);
   int_value = 1;
-  girara_setting_add(gsession, "page-padding",          &int_value,   INT,    false, _("Padding between pages"),    cb_page_layout_value_changed, NULL);
+  girara_setting_add(gsession, "page-h-padding",        &int_value,   INT,    false, _("Horizontal padding between pages"), cb_page_layout_value_changed, NULL);
+  int_value = 1;
+  girara_setting_add(gsession, "page-v-padding",        &int_value,   INT,    false, _("Vertical padding between pages"), cb_page_layout_value_changed, NULL);
   int_value = 1;
   girara_setting_add(gsession, "pages-per-row",         &int_value,   INT,    false, _("Number of pages per row"),  cb_page_layout_value_changed, NULL);
   int_value = 1;
@@ -255,10 +274,10 @@ void config_load_default(zathura_t* zathura) {
   girara_setting_add(gsession, "render-loading-fg",      NULL,      STRING, false, _("'Loading ...' foreground color"),     cb_color_change, NULL);
   girara_setting_set(gsession, "render-loading-fg",      "#000000");
 
-  girara_setting_add(gsession, "index-fg",        "#DDDDDD", STRING, true, _("Index mode foreground color"), NULL, NULL);
-  girara_setting_add(gsession, "index-bg",        "#232323", STRING, true, _("Index mode background color"), NULL, NULL);
-  girara_setting_add(gsession, "index-active-fg", "#232323", STRING, true, _("Index mode foreground color (active element)"), NULL, NULL);
-  girara_setting_add(gsession, "index-active-bg", "#9FBC00", STRING, true, _("Index mode background color (active element)"), NULL, NULL);
+  girara_setting_add(gsession, "index-fg",        "#DDDDDD", STRING, false, _("Index mode foreground color"), cb_color, NULL);
+  girara_setting_add(gsession, "index-bg",        "#232323", STRING, false, _("Index mode background color"), cb_color, NULL);
+  girara_setting_add(gsession, "index-active-fg", "#232323", STRING, false, _("Index mode foreground color (active element)"), cb_color, NULL);
+  girara_setting_add(gsession, "index-active-bg", "#9FBC00", STRING, false, _("Index mode background color (active element)"), cb_color, NULL);
   girara_setting_add(gsession, "signature-success-color", NULL, STRING, false,
                      _("Color used to highlight valid signatures"), cb_color_change, NULL);
   girara_setting_set(gsession, "signature-success-color", "rgba(18%,80%,33%,0.9)");
@@ -363,8 +382,10 @@ void config_load_default(zathura_t* zathura) {
                                                                                                                        \
   girara_shortcut_add(gsession, 0, 0, "gg", sc_goto, (mode), TOP, NULL);                                               \
   girara_shortcut_add(gsession, 0, GDK_KEY_Home, NULL, sc_goto, (mode), TOP, NULL);                                    \
+  girara_shortcut_add(gsession, 0, GDK_KEY_KP_Home, NULL, sc_goto, (mode), TOP, NULL);                                 \
   girara_shortcut_add(gsession, 0, 0, "G", sc_goto, (mode), BOTTOM, NULL);                                             \
   girara_shortcut_add(gsession, 0, GDK_KEY_End, NULL, sc_goto, (mode), BOTTOM, NULL);                                  \
+  girara_shortcut_add(gsession, 0, GDK_KEY_KP_End, NULL, sc_goto, (mode), BOTTOM, NULL);                               \
                                                                                                                        \
   girara_shortcut_add(gsession, 0, GDK_KEY_m, NULL, sc_mark_add, (mode), 0, NULL);                                     \
   girara_shortcut_add(gsession, 0, GDK_KEY_apostrophe, NULL, sc_mark_evaluate, (mode), 0, NULL);                       \
@@ -372,9 +393,13 @@ void config_load_default(zathura_t* zathura) {
   girara_shortcut_add(gsession, 0, GDK_KEY_J, NULL, sc_navigate, (mode), NEXT, NULL);                                  \
   girara_shortcut_add(gsession, 0, GDK_KEY_K, NULL, sc_navigate, (mode), PREVIOUS, NULL);                              \
   girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_Right, NULL, sc_navigate, (mode), NEXT, NULL);                  \
+  girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_KP_Right, NULL, sc_navigate, (mode), NEXT, NULL);               \
   girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_Left, NULL, sc_navigate, (mode), PREVIOUS, NULL);               \
+  girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_KP_Left, NULL, sc_navigate, (mode), PREVIOUS, NULL);            \
   girara_shortcut_add(gsession, 0, GDK_KEY_Page_Down, NULL, sc_navigate, (mode), NEXT, NULL);                          \
+  girara_shortcut_add(gsession, 0, GDK_KEY_KP_Page_Down, NULL, sc_navigate, (mode), NEXT, NULL);                       \
   girara_shortcut_add(gsession, 0, GDK_KEY_Page_Up, NULL, sc_navigate, (mode), PREVIOUS, NULL);                        \
+  girara_shortcut_add(gsession, 0, GDK_KEY_KP_Page_Up, NULL, sc_navigate, (mode), PREVIOUS, NULL);                     \
   girara_shortcut_add(gsession, 0, GDK_KEY_Forward, NULL, sc_navigate, (mode), NEXT, NULL);                            \
   girara_shortcut_add(gsession, 0, GDK_KEY_Back, NULL, sc_navigate, (mode), PREVIOUS, NULL);                           \
                                                                                                                        \
@@ -391,17 +416,23 @@ void config_load_default(zathura_t* zathura) {
   girara_shortcut_add(gsession, 0, GDK_KEY_k, NULL, sc_scroll, (mode), UP, NULL);                                      \
   girara_shortcut_add(gsession, 0, GDK_KEY_l, NULL, sc_scroll, (mode), RIGHT, NULL);                                   \
   girara_shortcut_add(gsession, 0, GDK_KEY_Left, NULL, sc_scroll, (mode), LEFT, NULL);                                 \
+  girara_shortcut_add(gsession, 0, GDK_KEY_KP_Left, NULL, sc_scroll, (mode), LEFT, NULL);                              \
   girara_shortcut_add(gsession, 0, GDK_KEY_Up, NULL, sc_scroll, (mode), UP, NULL);                                     \
+  girara_shortcut_add(gsession, 0, GDK_KEY_KP_Up, NULL, sc_scroll, (mode), UP, NULL);                                  \
   girara_shortcut_add(gsession, 0, GDK_KEY_Down, NULL, sc_scroll, (mode), DOWN, NULL);                                 \
+  girara_shortcut_add(gsession, 0, GDK_KEY_KP_Down, NULL, sc_scroll, (mode), DOWN, NULL);                              \
   girara_shortcut_add(gsession, 0, GDK_KEY_H, NULL, sc_scroll, (mode), PAGE_TOP, NULL);                                \
   girara_shortcut_add(gsession, 0, GDK_KEY_L, NULL, sc_scroll, (mode), PAGE_BOTTOM, NULL);                             \
   girara_shortcut_add(gsession, 0, GDK_KEY_Right, NULL, sc_scroll, (mode), RIGHT, NULL);                               \
+  girara_shortcut_add(gsession, 0, GDK_KEY_KP_Right, NULL, sc_scroll, (mode), RIGHT, NULL);                            \
   girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_t, NULL, sc_scroll, (mode), HALF_LEFT, NULL);                \
                                                                                                                        \
   girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_k, NULL, sc_scroll, (mode), PARTIAL_UP, NULL);                  \
   girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_j, NULL, sc_scroll, (mode), PARTIAL_DOWN, NULL);                \
   girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_Up, NULL, sc_scroll, (mode), PARTIAL_UP, NULL);                 \
+  girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_KP_Up, NULL, sc_scroll, (mode), PARTIAL_UP, NULL);              \
   girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_Down, NULL, sc_scroll, (mode), PARTIAL_DOWN, NULL);             \
+  girara_shortcut_add(gsession, GDK_MOD1_MASK, GDK_KEY_KP_Down, NULL, sc_scroll, (mode), PARTIAL_DOWN, NULL);          \
                                                                                                                        \
   girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_d, NULL, sc_scroll, (mode), HALF_DOWN, NULL);                \
   girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_u, NULL, sc_scroll, (mode), HALF_UP, NULL);                  \
@@ -495,44 +526,59 @@ void config_load_default(zathura_t* zathura) {
   DEFAULT_MOUSE_EVENTS(FULLSCREEN)
 
   /* Index mode */
-  girara_shortcut_add(gsession, 0,                GDK_KEY_Tab,         NULL, sc_toggle_index,        INDEX,        0,            NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_k,           NULL, sc_navigate_index,      INDEX,        UP,           NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_j,           NULL, sc_navigate_index,      INDEX,        DOWN,         NULL);
-  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_d,           NULL, sc_navigate_index,      INDEX,        HALF_DOWN,    NULL);
-  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_u,           NULL, sc_navigate_index,      INDEX,        HALF_UP,      NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_j,           NULL, sc_navigate_index,      INDEX,        DOWN,         NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_h,           NULL, sc_navigate_index,      INDEX,        COLLAPSE,     NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_l,           NULL, sc_navigate_index,      INDEX,        EXPAND,       NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_L,           NULL, sc_navigate_index,      INDEX,        EXPAND_ALL,   NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_H,           NULL, sc_navigate_index,      INDEX,        COLLAPSE_ALL, NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_Up,          NULL, sc_navigate_index,      INDEX,        UP,           NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_Down,        NULL, sc_navigate_index,      INDEX,        DOWN,         NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_Left,        NULL, sc_navigate_index,      INDEX,        COLLAPSE,     NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_Right,       NULL, sc_navigate_index,      INDEX,        EXPAND,       NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_space,       NULL, sc_navigate_index,      INDEX,        SELECT,       NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_Return,      NULL, sc_navigate_index,      INDEX,        SELECT,       NULL);
-  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_j,           NULL, sc_navigate_index,      INDEX,        SELECT,       NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_q,           NULL, sc_quit,                INDEX,        0,            NULL);
-  girara_shortcut_add(gsession, 0,                0,                   "gg", sc_navigate_index,      INDEX,        TOP,          NULL);
-  girara_shortcut_add(gsession, 0,                0,                   "G",  sc_navigate_index,      INDEX,        BOTTOM,       NULL);
-  girara_shortcut_add(gsession, 0,                GDK_KEY_Escape,      NULL, sc_toggle_index,        INDEX,        0,            NULL);
-  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_bracketleft, NULL, sc_toggle_index,        INDEX,        0,            NULL);
-  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_c,           NULL, sc_toggle_index,        INDEX,        0,            NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_Tab,         NULL, sc_toggle_index,        INDEX,        0,                  NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_k,           NULL, sc_navigate_index,      INDEX,        UP,                 NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_j,           NULL, sc_navigate_index,      INDEX,        DOWN,               NULL);
+  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_d,           NULL, sc_navigate_index,      INDEX,        HALF_DOWN,          NULL);
+  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_u,           NULL, sc_navigate_index,      INDEX,        HALF_UP,            NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_h,           NULL, sc_navigate_index,      INDEX,        COLLAPSE,           NULL);
+  girara_shortcut_add(gsession, 0,                0,                   "zc", sc_navigate_index,      INDEX,        COLLAPSE,           NULL);
+  girara_shortcut_add(gsession, 0,                0,                   "zC", sc_navigate_index,      INDEX,        COLLAPSE_RECURSIVE, NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_H,           NULL, sc_navigate_index,      INDEX,        COLLAPSE_ALL,       NULL);
+  girara_shortcut_add(gsession, 0,                0,                   "zM", sc_navigate_index,      INDEX,        COLLAPSE_ALL,       NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_l,           NULL, sc_navigate_index,      INDEX,        EXPAND,             NULL);
+  girara_shortcut_add(gsession, 0,                0,                   "zo", sc_navigate_index,      INDEX,        EXPAND,             NULL);
+  girara_shortcut_add(gsession, 0,                0,                   "zO", sc_navigate_index,      INDEX,        EXPAND_RECURSIVE,   NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_L,           NULL, sc_navigate_index,      INDEX,        EXPAND_ALL,         NULL);
+  girara_shortcut_add(gsession, 0,                0,                   "zR", sc_navigate_index,      INDEX,        EXPAND_ALL,         NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_Up,          NULL, sc_navigate_index,      INDEX,        UP,                 NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_KP_Up,       NULL, sc_navigate_index,      INDEX,        UP,                 NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_Down,        NULL, sc_navigate_index,      INDEX,        DOWN,               NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_KP_Down,     NULL, sc_navigate_index,      INDEX,        DOWN,               NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_Left,        NULL, sc_navigate_index,      INDEX,        COLLAPSE,           NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_KP_Left,     NULL, sc_navigate_index,      INDEX,        COLLAPSE,           NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_Right,       NULL, sc_navigate_index,      INDEX,        EXPAND,             NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_KP_Right,    NULL, sc_navigate_index,      INDEX,        EXPAND,             NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_space,       NULL, sc_navigate_index,      INDEX,        SELECT,             NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_Return,      NULL, sc_navigate_index,      INDEX,        SELECT,             NULL);
+  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_j,           NULL, sc_navigate_index,      INDEX,        SELECT,             NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_q,           NULL, sc_quit,                INDEX,        0,                  NULL);
+  girara_shortcut_add(gsession, 0,                0,                   "gg", sc_navigate_index,      INDEX,        TOP,                NULL);
+  girara_shortcut_add(gsession, 0,                0,                   "G",  sc_navigate_index,      INDEX,        BOTTOM,             NULL);
+  girara_shortcut_add(gsession, 0,                GDK_KEY_Escape,      NULL, sc_toggle_index,        INDEX,        0,                  NULL);
+  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_bracketleft, NULL, sc_toggle_index,        INDEX,        0,                  NULL);
+  girara_shortcut_add(gsession, GDK_CONTROL_MASK, GDK_KEY_c,           NULL, sc_toggle_index,        INDEX,        0,                  NULL);
 
   /* Presentation mode */
-  girara_shortcut_add(gsession, 0,              GDK_KEY_J,         NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_Down,      NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_Right,     NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_Page_Down, NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_Forward,   NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_space,     NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_K,         NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_Left,      NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_Up,        NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_Page_Up,   NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_Back,      NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
-  girara_shortcut_add(gsession, GDK_SHIFT_MASK, GDK_KEY_space,     NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
-  girara_shortcut_add(gsession, 0,              GDK_KEY_BackSpace, NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_J,            NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_Down,         NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_KP_Down,      NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_Right,        NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_KP_Right,     NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_Page_Down,    NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_KP_Page_Down, NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_Forward,      NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_space,        NULL, sc_navigate,            PRESENTATION, NEXT,         NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_K,            NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_Left,         NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_KP_Left,      NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_Up,           NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_KP_Up,        NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_Page_Up,      NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_KP_Page_Up,   NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_Back,         NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, GDK_SHIFT_MASK, GDK_KEY_space,        NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
+  girara_shortcut_add(gsession, 0,              GDK_KEY_BackSpace,    NULL, sc_navigate,            PRESENTATION, PREVIOUS,     NULL);
 
   girara_shortcut_add(gsession, 0,              GDK_KEY_F5,        NULL, sc_toggle_presentation, PRESENTATION, 0,            NULL);
 
@@ -622,42 +668,44 @@ void config_load_default(zathura_t* zathura) {
   girara_shortcut_mapping_add(gsession, "zoom",                sc_zoom);
 
   /* add argument mappings */
-  girara_argument_mapping_add(gsession, "backward",     BACKWARD);
-  girara_argument_mapping_add(gsession, "bottom",       BOTTOM);
-  girara_argument_mapping_add(gsession, "default",      DEFAULT);
-  girara_argument_mapping_add(gsession, "collapse",     COLLAPSE);
-  girara_argument_mapping_add(gsession, "collapse-all", COLLAPSE_ALL);
-  girara_argument_mapping_add(gsession, "down",         DOWN);
-  girara_argument_mapping_add(gsession, "expand",       EXPAND);
-  girara_argument_mapping_add(gsession, "expand-all",   EXPAND_ALL);
-  girara_argument_mapping_add(gsession, "select",       SELECT);
-  girara_argument_mapping_add(gsession, "toggle",       TOGGLE);
-  girara_argument_mapping_add(gsession, "forward",      FORWARD);
-  girara_argument_mapping_add(gsession, "full-down",    FULL_DOWN);
-  girara_argument_mapping_add(gsession, "full-up",      FULL_UP);
-  girara_argument_mapping_add(gsession, "half-down",    HALF_DOWN);
-  girara_argument_mapping_add(gsession, "half-up",      HALF_UP);
-  girara_argument_mapping_add(gsession, "partial-down", PARTIAL_DOWN);
-  girara_argument_mapping_add(gsession, "partial-up",   PARTIAL_UP);
-  girara_argument_mapping_add(gsession, "full-right",   FULL_RIGHT);
-  girara_argument_mapping_add(gsession, "full-left",    FULL_LEFT);
-  girara_argument_mapping_add(gsession, "half-right",   HALF_RIGHT);
-  girara_argument_mapping_add(gsession, "half-left",    HALF_LEFT);
-  girara_argument_mapping_add(gsession, "in",           ZOOM_IN);
-  girara_argument_mapping_add(gsession, "left",         LEFT);
-  girara_argument_mapping_add(gsession, "next",         NEXT);
-  girara_argument_mapping_add(gsession, "out",          ZOOM_OUT);
-  girara_argument_mapping_add(gsession, "page-top",     PAGE_TOP);
-  girara_argument_mapping_add(gsession, "page-bottom",  PAGE_BOTTOM);
-  girara_argument_mapping_add(gsession, "previous",     PREVIOUS);
-  girara_argument_mapping_add(gsession, "right",        RIGHT);
-  girara_argument_mapping_add(gsession, "specific",     ZOOM_SPECIFIC);
-  girara_argument_mapping_add(gsession, "top",          TOP);
-  girara_argument_mapping_add(gsession, "up",           UP);
-  girara_argument_mapping_add(gsession, "best-fit",     ZATHURA_ADJUST_BESTFIT);
-  girara_argument_mapping_add(gsession, "width",        ZATHURA_ADJUST_WIDTH);
-  girara_argument_mapping_add(gsession, "rotate-cw",    ROTATE_CW);
-  girara_argument_mapping_add(gsession, "rotate-ccw",   ROTATE_CCW);
+  girara_argument_mapping_add(gsession, "backward",           BACKWARD);
+  girara_argument_mapping_add(gsession, "bottom",             BOTTOM);
+  girara_argument_mapping_add(gsession, "default",            DEFAULT);
+  girara_argument_mapping_add(gsession, "collapse",           COLLAPSE);
+  girara_argument_mapping_add(gsession, "collapse-recursive", COLLAPSE_RECURSIVE);
+  girara_argument_mapping_add(gsession, "collapse-all",       COLLAPSE_ALL);
+  girara_argument_mapping_add(gsession, "down",               DOWN);
+  girara_argument_mapping_add(gsession, "expand",             EXPAND);
+  girara_argument_mapping_add(gsession, "expand-recursive",   EXPAND_RECURSIVE);
+  girara_argument_mapping_add(gsession, "expand-all",         EXPAND_ALL);
+  girara_argument_mapping_add(gsession, "select",             SELECT);
+  girara_argument_mapping_add(gsession, "toggle",             TOGGLE);
+  girara_argument_mapping_add(gsession, "forward",            FORWARD);
+  girara_argument_mapping_add(gsession, "full-down",          FULL_DOWN);
+  girara_argument_mapping_add(gsession, "full-up",            FULL_UP);
+  girara_argument_mapping_add(gsession, "half-down",          HALF_DOWN);
+  girara_argument_mapping_add(gsession, "half-up",            HALF_UP);
+  girara_argument_mapping_add(gsession, "partial-down",       PARTIAL_DOWN);
+  girara_argument_mapping_add(gsession, "partial-up",         PARTIAL_UP);
+  girara_argument_mapping_add(gsession, "full-right",         FULL_RIGHT);
+  girara_argument_mapping_add(gsession, "full-left",          FULL_LEFT);
+  girara_argument_mapping_add(gsession, "half-right",         HALF_RIGHT);
+  girara_argument_mapping_add(gsession, "half-left",          HALF_LEFT);
+  girara_argument_mapping_add(gsession, "in",                 ZOOM_IN);
+  girara_argument_mapping_add(gsession, "left",               LEFT);
+  girara_argument_mapping_add(gsession, "next",               NEXT);
+  girara_argument_mapping_add(gsession, "out",                ZOOM_OUT);
+  girara_argument_mapping_add(gsession, "page-top",           PAGE_TOP);
+  girara_argument_mapping_add(gsession, "page-bottom",        PAGE_BOTTOM);
+  girara_argument_mapping_add(gsession, "previous",           PREVIOUS);
+  girara_argument_mapping_add(gsession, "right",              RIGHT);
+  girara_argument_mapping_add(gsession, "specific",           ZOOM_SPECIFIC);
+  girara_argument_mapping_add(gsession, "top",                TOP);
+  girara_argument_mapping_add(gsession, "up",                 UP);
+  girara_argument_mapping_add(gsession, "best-fit",           ZATHURA_ADJUST_BESTFIT);
+  girara_argument_mapping_add(gsession, "width",              ZATHURA_ADJUST_WIDTH);
+  girara_argument_mapping_add(gsession, "rotate-cw",          ROTATE_CW);
+  girara_argument_mapping_add(gsession, "rotate-ccw",         ROTATE_CCW);
   /* clang-format on */
 }
 
