@@ -36,13 +36,14 @@ static void zathura_jumplist_append_jump(zathura_t* zathura) {
 }
 
 static void zathura_jumplist_save(zathura_t* zathura) {
-  g_return_if_fail(zathura != NULL && zathura->document != NULL);
+  g_return_if_fail(zathura_has_document(zathura) == true);
 
   zathura_jump_t* cur = zathura_jumplist_current(zathura);
   if (cur != NULL) {
-    cur->x    = zathura_document_get_position_x(zathura->document);
-    cur->y    = zathura_document_get_position_y(zathura->document);
-    cur->page = zathura_document_get_current_page_number(zathura->document);
+    zathura_document_t* document = zathura_get_document(zathura);
+    cur->x                       = zathura_document_get_position_x(document);
+    cur->y                       = zathura_document_get_position_y(document);
+    cur->page                    = zathura_document_get_current_page_number(document);
   }
 }
 
@@ -97,16 +98,16 @@ void zathura_jumplist_trim(zathura_t* zathura) {
 }
 
 void zathura_jumplist_add(zathura_t* zathura) {
-  g_return_if_fail(zathura != NULL && zathura->document != NULL && zathura->jumplist.list != NULL);
+  g_return_if_fail(zathura_has_document(zathura) == true && zathura->jumplist.list != NULL);
 
-  double x = zathura_document_get_position_x(zathura->document);
-  double y = zathura_document_get_position_y(zathura->document);
+  zathura_document_t* document = zathura_get_document(zathura);
+  double x                     = zathura_document_get_position_x(document);
+  double y                     = zathura_document_get_position_y(document);
 
   if (zathura->jumplist.size != 0) {
     zathura_jumplist_reset_current(zathura);
 
     zathura_jump_t* cur = zathura_jumplist_current(zathura);
-
     if (cur != NULL) {
       if (fabs(cur->x - x) <= DBL_EPSILON && fabs(cur->y - y) <= DBL_EPSILON) {
         return;
@@ -119,6 +120,13 @@ void zathura_jumplist_add(zathura_t* zathura) {
   zathura_jumplist_save(zathura);
 }
 
+void zathura_jumplist_set_max_size(zathura_t* zathura, size_t max_size) {
+  zathura->jumplist.max_size = max_size;
+  if (zathura->jumplist.list != NULL && zathura->jumplist.size != 0) {
+    zathura_jumplist_trim(zathura);
+  }
+}
+
 bool zathura_jumplist_load(zathura_t* zathura, const char* file) {
   g_return_val_if_fail(zathura != NULL && file != NULL, false);
 
@@ -126,14 +134,14 @@ bool zathura_jumplist_load(zathura_t* zathura, const char* file) {
     return false;
   }
 
-  zathura->jumplist.list = zathura_db_load_jumplist(zathura->database, file);
-
-  if (zathura->jumplist.list == NULL) {
+  girara_list_t* list = zathura_db_load_jumplist(zathura->database, file);
+  if (list == NULL) {
     girara_error("Failed to load the jumplist from the database");
-
     return false;
   }
 
+  girara_list_free(zathura->jumplist.list);
+  zathura->jumplist.list = list;
   zathura->jumplist.size = girara_list_size(zathura->jumplist.list);
 
   if (zathura->jumplist.size != 0) {
@@ -148,3 +156,26 @@ bool zathura_jumplist_load(zathura_t* zathura, const char* file) {
   return true;
 }
 
+void zathura_jumplist_init(zathura_t* zathura, size_t max_size) {
+  zathura->jumplist.max_size = max_size;
+  zathura->jumplist.list     = girara_list_new_with_free(g_free);
+  zathura->jumplist.size     = 0;
+  zathura->jumplist.cur      = NULL;
+}
+
+bool zathura_jumplist_is_initalized(zathura_t* zathura) {
+  return zathura->jumplist.list != NULL;
+}
+
+void zathura_jumplist_clear(zathura_t* zathura) {
+  if (zathura == NULL) {
+    return;
+  }
+
+  /* remove jump list */
+  girara_list_iterator_free(zathura->jumplist.cur);
+  zathura->jumplist.cur = NULL;
+  girara_list_free(zathura->jumplist.list);
+  zathura->jumplist.list = NULL;
+  zathura->jumplist.size = 0;
+}
\ No newline at end of file
