@@ -45,8 +45,10 @@ enum {
   CONTINUOUS,
   DELETE_LAST,
   EXPAND,
+  EXPAND_RECURSIVE,
   EXPAND_ALL,
   COLLAPSE_ALL,
+  COLLAPSE_RECURSIVE,
   COLLAPSE,
   TOGGLE,
   SELECT,
